@@ -11,8 +11,9 @@ fn generate_bindings_multi(prefix: &str) -> Result<(), Error> {
     let namespace_mappings = NamespaceMappings::new("My.Company").add("common", "My.Company.Common");
 
     let config = Config {
-        dll_name: "example_complex".to_string(),
+        dll_name: "interoptopus_reference_project".to_string(),
         namespace_mappings,
+        emit_rust_visibility: true,
         ..Config::default()
     };
 
@@ -31,6 +32,7 @@ fn generate_bindings_multi(prefix: &str) -> Result<(), Error> {
 }
 
 #[test]
+#[cfg_attr(miri, ignore)]
 fn bindings_match_reference() -> Result<(), Error> {
     generate_bindings_multi("tests/output/Interop")?;
 
@@ -41,6 +43,7 @@ fn bindings_match_reference() -> Result<(), Error> {
 }
 
 #[test]
+#[cfg_attr(miri, ignore)]
 fn bindings_work() -> Result<(), Error> {
     generate_bindings_multi("tests/output/Interop")?;
 
